==> PathOfBuilding-1.4.155.zip: Data/Uniques/flask.lua <==
-- Item data (c) Grinding Gear Games

return {
-- Flask: Life
[[
Blood of the Karui
Sanctified Life Flask
League: Domination, Nemesis
Variant: Pre 2.6.0
Variant: Current
Requires Level 50
(5-20)% increased Recovery Speed
{variant:1}No Life Recovery Applies during Flask effect
{variant:2}100% increased Amount Recovered
Recover Full Life at the end of the Flask effect
]],
-- Flask: Mana
[[
Doedre's Elixir
Greater Mana Flask
Variant: Pre 2.0.0
Variant: Current
Requires Level 12
Implicits: 0
Removes 20% of your maximum Energy Shield on use
You take 10% of your maximum Life as Chaos Damage on use
You gain a Power Charge on use
You gain a Frenzy Charge on use
You gain an Endurance Charge on use
{variant:1}(50-100)% increased Charges used
{variant:2}(120-150)% increased Charges used
]],[[
Lavianga's Spirit
Sanctified Mana Flask
League: Domination, Nemesis
Requires Level 50
(30-50)% increased Amount Recovered
100% increased Recovery Speed
Your Skills have no Mana Cost during Flask effect
]],[[
Zerphi's Last Breath
Grand Mana Flask
Variant: {2_6}Pre 3.5.0
Variant: Current
League: Perandus
Requires Level 18
50% increased Charges used
{variant:1}Skills used during Flask effect grant 800% of Mana Cost as Life
{variant:2}Skills used during Flask effect grant (450-600)% of Mana Cost as Life over 4 Seconds
]],
-- Flask: Hybrid
[[
Divination Distillate
Large Hybrid Flask
Variant: Pre 1.1.0
Variant: Pre 2.2.0
Variant: {2_6}Pre 3.5.0
Variant: Current
Requires Level 30
(40-60)% increased Rarity of Items found during Flask effect
{variant:1}(20-25)% increased Quantity of Items found during Flask effect
{variant:2,3,4}(12-18)% increased Quantity of Items found during Flask effect
25% increased Light Radius during Flask effect
{variant:1,2}+6% to all maximum Elemental Resistances during Flask effect
{variant:3}+4% to all maximum Elemental Resistances during Flask effect
{variant:4}+50% to all Elemental Resistances during Flask Effect
]],[[
The Writhing Jar
Hallowed Hybrid Flask
Requires Level 60
(75-65)% reduced Amount Recovered
Instant Recovery
2 Enemy Writhing Worms escape the Flask when used
(20-10)% reduced Charges used
]],
-- Flask: Utility
[[
Atziri's Promise
Amethyst Flask
Source: Drops from unique{Atziri, Queen of the Vaal} in normal{The Apex of Sacrifice}
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 68
2% of Chaos Damage Leeched as Life during Flask effect
{variant:1}Gain (22-25)% of Physical Damage as Extra Chaos Damage during effect
{variant:2}Gain (15-20)% of Physical Damage as Extra Chaos Damage during effect
{variant:1}Gain (13-15)% of Elemental Damage as Extra Chaos Damage during effect
{variant:2}Gain (10-15)% of Elemental Damage as Extra Chaos Damage during effect
]],[[
Bottled Faith
Sulphur Flask
League: Synthesis
Requires Level 35
Creates Consecrated Ground on Use
(30-50)% increased Duration
Consecrated Ground created by this Flask has Tripled Radius
+(1.00-2.00)% to Critical Strike Chance against Enemies on Consecrated Ground during Effect
Consecrated Ground created during Effect applies (7–10)% increased Damage taken to Enemies
]],[[
Coralito's Signature
Diamond Flask
Requires Level 27
Take 30 Chaos Damage per Second during Flask effect
25% chance to Poison on Hit during Flask effect
Your Critical Strikes do not deal extra Damage during Flask effect
(50-75)% increased Duration of Poisons you inflict during Flask effect
Grants Perfect Agony during Flask effect
]],[[
Coruscating Elixir
Ruby Flask
Variant: Pre 2.6.0
Variant: Current
Requires Level 18
Implicits: 0
{variant:2}100% increased Duration
Chaos Damage does not bypass Energy Shield during effect
Removes all but one Life on use
Removed life is regenerated as Energy Shield over 2 seconds
]],[[
Cinderswallow Urn
Silver Flask
League: Betrayal
Source: Drops from unique{Catarina, Master of Undeath}
Variant: Crit Chance
Variant: Damage Taken is Leeched as Life
Variant: Item Rarity
Variant: Reduced Mana Cost
Variant: Movement Speed/Stun Avoidance
Variant: Life Regen
Requires Level 22
Implicits: 0
Recharges 1 Charge when you consume an Ignited Corpse
Enemies Ignited by you during Flask Effect take 10% increased Damage
Recover (1–3)% of Life when you Kill an Enemy during Flask Effect
Recover (1–3)% of Mana when you Kill an Enemy during Flask Effect
Recover (1–3)% of Energy Shield when you Kill an Enemy during Flask Effect
{variant:1}{crafted}(60-80)% increased Critical Strike Chance during Flask Effect
{variant:2}{crafted}15% of Damage Taken from Hits is Leeched as Life during Flask Effect
{variant:3}{crafted}(20-30)% increased Rarity of Items found during Flask Effect
{variant:4}{crafted}(25-20)% reduced Mana Cost of Skills during Flask Effect
{variant:5}{crafted}(8-12)% increased Movement Speed during Flask effect
{variant:5}{crafted}50% Chance to avoid being Stunned during Flask Effect
{variant:6}{crafted}3% of Life Regenerated per second during Flask Effect
]],[[
Dying Sun
Ruby Flask
Source: Drops from unique{The Shaper}
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 68
(-10-10)% increased Charges used
{variant:1}30% increased Area of Effect during Flask Effect
{variant:2}(15-25)% increased Area of Effect during Flask Effect
2 additional Projectiles during Flask Effect
]],[[
Forbidden Taste
Quartz Flask
Variant: Pre 1.2.3
Variant: Pre 2.6.0
Variant: Current
Requires Level 27
{variant:1,2}50% increased Charges used
{variant:1}Recover 50% of your maximum Life on use
{variant:2}Recover 75% of your maximum Life on use
{variant:3}Recover (75-100)% of your maximum Life on use
{variant:1}15% of maximum Life taken as Chaos Damage per second
{variant:2,3}8% of maximum Life taken as Chaos Damage per second
]],[[
Kiara's Determination
Silver Flask
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 22
Implicits: 0
Immune to Freeze, Chill, Curses and Stuns during Flask Effect
{variant:1}50% reduced Duration
{variant:2}60% reduced Duration
]],[[
Lion's Roar
Granite Flask
Variant: Pre 2.2.0
Variant: {2_6}Pre 3.0.0
Variant: Pre 3.1.0
Variant: Current
Requires Level 27
Implicits: 0
{variant:1,2,3}Adds Knockback during Flask effect
{variant:4}Adds Knockback to Melee Attacks during Flask effect
75% chance to cause Enemies to Flee on use
{variant:1}(70-100)% increased Charges used
{variant:1}30% more Melee Physical Damage during effect
{variant:2}(30-35)% more Melee Physical Damage during effect
{variant:3,4}(20-25)% more Melee Physical Damage during effect
Knocks Back Enemies in an Area on Flask use
]],[[
Rotgut
Quicksilver Flask
Variant: Pre 2.2.0
Variant: Pre 2.6.0
Variant: Current
Requires Level 40
{variant:1}(100-150)% increased Charges used
{variant:2,3}(50-100)% increased Charges used
{variant:3}50% increased Duration
{variant:1,2}15% chance to gain a Flask Charge when you deal a Critical Strike
{variant:3}50% chance to gain a Flask Charge when you deal a Critical Strike
(10-30)% increased Movement Speed during Flask effect
Consumes Frenzy Charges on use
{variant:1,2}Gain Onslaught for 1 second per Frenzy Charge on use
{variant:3}Gain Onslaught for 2 second per Frenzy Charge on use
]],[[
Rumi's Concoction
Granite Flask
Variant: Pre 1.3.0
Variant: Pre 2.5.0
Variant: Current
Requires Level 68
{variant:1}(30-40)% Chance to Block during Flask effect
{variant:2}(20-30)% Chance to Block during Flask effect
{variant:3}(14-20)% Chance to Block during Flask effect
{variant:1}(15-20)% Chance to Block Spells during Flask effect
{variant:2}(10-15)% Chance to Block Spells during Flask effect
{variant:3}(6-10)% Chance to Block Spells during Flask effect
]],[[
Sin's Rebirth
Stibnite Flask
Requires Level 14
Implicits: 1
Creates a Smoke Cloud on Use
Gain Unholy Might during Flask Effect
Immunity to Ignite during Flask effect
Removes Burning on use
]],[[
Soul Catcher
Quartz Flask
League: Incursion
Source: Drops from unique{The Vaal Omnitect}
Upgrade: Upgrades to unique{Soul Ripper} via currency{Vial of the Ghost}
Requires Level 27
Cannot gain Mana during effect
Vaal Skills deal (60-100)% increased Damage during effect
Vaal Skills have 25% reduced Soul Cost during effect
Vaal Skills used during effect have (20-40)% reduced Soul Gain Prevention Duration
]],[[
Soul Ripper
Quartz Flask
League: Incursion
Source: Upgraded from unique{Soul Catcher} via currency{Vial of the Ghost}
Requires Level 27
100% increased Charges used
Vaal Skills deal (30-40)% more Damage during effect
Vaal Skills used during effect do not apply Soul Gain Prevention
Gains no Charges During effect of any Soul Ripper Flask
]],[[
Taste of Hate
Sapphire Flask
Variant: Pre 2.2.0
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 18
{variant:1}30% of Physical Damage taken as Cold Damage during Flask effect
{variant:2,3}20% of Physical Damage taken as Cold Damage during Flask effect
{variant:1,2}Gain (20-30)% of Physical Damage as Extra Cold Damage during effect
{variant:3}Gain (15-20)% of Physical Damage as Extra Cold Damage during effect
30% chance to Avoid being Chilled during Flask effect
30% chance to Avoid being Frozen during Flask effect
]],[[
The Overflowing Chalice
Sulphur Flask
Requires Level 35
Implicits: 1
Creates Consecrated Ground on Use
100% increased Charge Recovery
(10-20)% increased Duration
Gains no Charges during Effect of any Overflowing Chalice Flask
100% increased Charges gained by Other Flasks during Flask Effect
]],[[
The Sorrow of the Divine
Sulphur Flask
League: Legion
Source: Drops from normal{Templar} legion
Requires Level 35
Implicits: 1
Creates Consecrated Ground on Use
(25-50)% increased Duration
Zealot's Oath during Flask effect
Life Recovery from Flasks also applies to Energy Shield during Flask Effect
]],[[
Vessel of Vinktar
Topaz Flask
Source: Drops from unique{Avatar of Thunder} in unique{The Vinktar Square}
Variant: Pre 2.2.0 (Penetration)
Variant: Pre 2.2.0 (Spells)
Variant: Pre 2.2.0 (Attacks)
Variant: Pre 2.2.0 (Conversion)
Variant: Pre 3.0.0 (Penetration)
Variant: Pre 3.0.0 (Spells)
Variant: Pre 3.0.0 (Attacks)
Variant: {2_6}Pre 3.0.0 (Conversion)
Variant: Current (Penetration)
Variant: Current (Spells)
Variant: Current (Attacks)
Variant: Current (Conversion)
Requires Level 68
{variant:5,6,7,8,9,10,11,12}(80-100)% increased Charges used
{variant:1,2,3,4,5,6,7,8}Shocks nearby Enemies during Flask effect
{variant:9,10,11,12}Shocks nearby Enemies during Flask effect, causing 10% increased Damage taken
{variant:1,2,3,4,5,6,7,8}You are Shocked during Flask effect
{variant:9,10,11,12}You are Shocked during Flask effect, causing 50% increased Damage taken
{variant:1,2,3,4}30% of Lightning Damage Leeched as Life during Flask effect
{variant:5,6,7,8,9,10,11,12}20% of Lightning Damage Leeched as Life during Flask effect
{variant:1,2,3,4}30% of Lightning Damage Leeched as Mana during Flask effect
{variant:5,6,7,8}20% of Lightning Damage Leeched as Mana during Flask effect
{variant:1,2,3,4}Leech applies instantly during Flask effect
{variant:1,5,9}Damage Penetrates 10% Lightning Resistance during Flask effect
{variant:2,6,10}Adds (15-25) to (70-90) Lightning Damage to Spells during Flask effect
{variant:3,7,11}Adds (25-35) to (110-130) Lightning Damage to Attacks during Flask effect
{variant:4,8,12}20% of Physical Damage Converted to Lightning during Flask effect
]],[[
The Wise Oak
Bismuth Flask
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 8
Implicits: 0
During Flask Effect, 10% reduced Damage taken of each Element for which your Uncapped
Elemental Resistance is lowest
{variant:1}During Flask Effect, Damage Penetrates 20% Resistance of each Element for which your
Uncapped Elemental Resistance is highest
{variant:2}During Flask Effect, Damage Penetrates (10-15)% Resistance of each Element for which your
Uncapped Elemental Resistance is highest
]],[[
Witchfire Brew
Stibnite Flask
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 48
Implicits: 1
Creates a Smoke Cloud on Use
50% increased Charges used
{variant:1}(50-70)% increased Damage Over Time during Flask Effect
{variant:2}(25-40)% increased Damage Over Time during Flask Effect
Grants level 21 Despair Curse Aura during Flask Effect
]],
}

==> PathOfBuilding-1.4.168.zip: Data/Uniques/flask.lua <==
-- Item data (c) Grinding Gear Games

return {
-- Flask: Life
[[
Blood of the Karui
Sanctified Life Flask
League: Domination, Nemesis
Variant: Pre 2.6.0
Variant: Current
Requires Level 50
(5-20)% increased Recovery Speed
{variant:1}No Life Recovery Applies during Flask effect
{variant:2}100% increased Amount Recovered
Recover Full Life at the end of the Flask effect
]],
-- Flask: Mana
[[
Doedre's Elixir
Greater Mana Flask
Variant: Pre 2.0.0
Variant: Current
Requires Level 12
Implicits: 0
Removes 20% of your maximum Energy Shield on use
You take 10% of your maximum Life as Chaos Damage on use
You gain a Power Charge on use
You gain a Frenzy Charge on use
You gain an Endurance Charge on use
{variant:1}(50-100)% increased Charges used
{variant:2}(120-150)% increased Charges used
]],[[
Lavianga's Spirit
Sanctified Mana Flask
League: Domination, Nemesis
Requires Level 50
(30-50)% increased Amount Recovered
100% increased Recovery Speed
Your Skills have no Mana Cost during Flask effect
]],[[
Zerphi's Last Breath
Grand Mana Flask
Variant: {2_6}Pre 3.5.0
Variant: Current
League: Perandus
Requires Level 18
50% increased Charges used
{variant:1}Skills used during Flask effect grant 800% of Mana Cost as Life
{variant:2}Skills used during Flask effect grant (450-600)% of Mana Cost as Life over 4 Seconds
]],
-- Flask: Hybrid
[[
Divination Distillate
Large Hybrid Flask
Variant: Pre 1.1.0
Variant: Pre 2.2.0
Variant: {2_6}Pre 3.5.0
Variant: Current
Requires Level 30
(40-60)% increased Rarity of Items found during Flask effect
{variant:1}(20-25)% increased Quantity of Items found during Flask effect
{variant:2,3,4}(12-18)% increased Quantity of Items found during Flask effect
25% increased Light Radius during Flask effect
{variant:1,2}+6% to all maximum Elemental Resistances during Flask effect
{variant:3}+4% to all maximum Elemental Resistances during Flask effect
{variant:4}+50% to all Elemental Resistances during Flask Effect
]],[[
The Writhing Jar
Hallowed Hybrid Flask
Requires Level 60
(75-65)% reduced Amount Recovered
Instant Recovery
2 Enemy Writhing Worms escape the Flask when used
(20-10)% reduced Charges used
]],
-- Flask: Utility
[[
Atziri's Promise
Amethyst Flask
Source: Drops from unique{Atziri, Queen of the Vaal} in normal{The Apex of Sacrifice}
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 68
2% of Chaos Damage Leeched as Life during Flask effect
{variant:1}Gain (22-25)% of Physical Damage as Extra Chaos Damage during effect
{variant:2}Gain (15-20)% of Physical Damage as Extra Chaos Damage during effect
{variant:1}Gain (13-15)% of Elemental Damage as Extra Chaos Damage during effect
{variant:2}Gain (10-15)% of Elemental Damage as Extra Chaos Damage during effect
]],[[
Bottled Faith
Sulphur Flask
League: Synthesis
Requires Level 35
Creates Consecrated Ground on Use
(30-50)% increased Duration
Consecrated Ground created by this Flask has Tripled Radius
+(1.00-2.00)% to Critical Strike Chance against Enemies on Consecrated Ground during Effect
Consecrated Ground created during Effect applies (7-10)% increased Damage taken to Enemies
]],[[
Coralito's Signature
Diamond Flask
Requires Level 27
Take 30 Chaos Damage per Second during Flask effect
25% chance to Poison on Hit during Flask effect
Your Critical Strikes do not deal extra Damage during Flask effect
(50-75)% increased Duration of Poisons you inflict during Flask effect
Grants Perfect Agony during Flask effect
]],[[
Coruscating Elixir
Ruby Flask
Variant: Pre 2.6.0
Variant: Current
Requires Level 18
Implicits: 0
{variant:2}100% increased Duration
Chaos Damage does not bypass Energy Shield during effect
Removes all but one Life on use
Removed life is regenerated as Energy Shield over 2 seconds
]],[[
Cinderswallow Urn
Silver Flask
League: Betrayal
Source: Drops from unique{Catarina, Master of Undeath}
Variant: Crit Chance
Variant: Damage Taken is Leeched as Life
Variant: Item Rarity
Variant: Reduced Mana Cost
Variant: Movement Speed/Stun Avoidance
Variant: Life Regen
Requires Level 22
Implicits: 0
Recharges 1 Charge when you consume an Ignited Corpse
Enemies Ignited by you during Flask Effect take 10% increased Damage
Recover (1-3)% of Life when you Kill an Enemy during Flask Effect
Recover (1-3)% of Mana when you Kill an Enemy during Flask Effect
Recover (1-3)% of Energy Shield when you Kill an Enemy during Flask Effect
{variant:1}{crafted}(60-80)% increased Critical Strike Chance during Flask Effect
{variant:2}{crafted}15% of Damage Taken from Hits is Leeched as Life during Flask Effect
{variant:3}{crafted}(20-30)% increased Rarity of Items found during Flask Effect
{variant:4}{crafted}(25-20)% reduced Mana Cost of Skills during Flask Effect
{variant:5}{crafted}(8-12)% increased Movement Speed during Flask effect
{variant:5}{crafted}50% Chance to avoid being Stunned during Flask Effect
{variant:6}{crafted}3% of Life Regenerated per second during Flask Effect
]],[[
Dying Sun
Ruby Flask
Source: Drops from unique{The Shaper}
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 68
(-10-10)% increased Charges used
{variant:1}30% increased Area of Effect during Flask Effect
{variant:2}(15-25)% increased Area of Effect during Flask Effect
2 additional Projectiles during Flask Effect
]],[[
Forbidden Taste
Quartz Flask
Variant: Pre 1.2.3
Variant: Pre 2.6.0
Variant: Current
Requires Level 27
{variant:1,2}50% increased Charges used
{variant:1}Recover 50% of your maximum Life on use
{variant:2}Recover 75% of your maximum Life on use
{variant:3}Recover (75-100)% of your maximum Life on use
{variant:1}15% of maximum Life taken as Chaos Damage per second
{variant:2,3}8% of maximum Life taken as Chaos Damage per second
]],[[
Kiara's Determination
Silver Flask
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 22
Implicits: 0
Immune to Freeze, Chill, Curses and Stuns during Flask Effect
{variant:1}50% reduced Duration
{variant:2}60% reduced Duration
]],[[
Lion's Roar
Granite Flask
Variant: Pre 2.2.0
Variant: {2_6}Pre 3.0.0
Variant: Pre 3.1.0
Variant: Current
Requires Level 27
Implicits: 0
{variant:1,2,3}Adds Knockback during Flask effect
{variant:4}Adds Knockback to Melee Attacks during Flask effect
75% chance to cause Enemies to Flee on use
{variant:1}(70-100)% increased Charges used
{variant:1}30% more Melee Physical Damage during effect
{variant:2}(30-35)% more Melee Physical Damage during effect
{variant:3,4}(20-25)% more Melee Physical Damage during effect
Knocks Back Enemies in an Area on Flask use
]],[[
Rotgut
Quicksilver Flask
Variant: Pre 2.2.0
Variant: Pre 2.6.0
Variant: Current
Requires Level 40
{variant:1}(100-150)% increased Charges used
{variant:2,3}(50-100)% increased Charges used
{variant:3}50% increased Duration
{variant:1,2}15% chance to gain a Flask Charge when you deal a Critical Strike
{variant:3}50% chance to gain a Flask Charge when you deal a Critical Strike
(10-30)% increased Movement Speed during Flask effect
Consumes Frenzy Charges on use
{variant:1,2}Gain Onslaught for 1 second per Frenzy Charge on use
{variant:3}Gain Onslaught for 2 second per Frenzy Charge on use
]],[[
Rumi's Concoction
Granite Flask
Variant: Pre 1.3.0
Variant: Pre 2.5.0
Variant: Current
Requires Level 68
{variant:1}(30-40)% Chance to Block during Flask effect
{variant:2}(20-30)% Chance to Block during Flask effect
{variant:3}(14-20)% Chance to Block during Flask effect
{variant:1}(15-20)% Chance to Block Spells during Flask effect
{variant:2}(10-15)% Chance to Block Spells during Flask effect
{variant:3}(6-10)% Chance to Block Spells during Flask effect
]],[[
Sin's Rebirth
Stibnite Flask
Requires Level 14
Implicits: 1
Creates a Smoke Cloud on Use
Gain Unholy Might during Flask Effect
Immunity to Ignite during Flask effect
Removes Burning on use
]],[[
Soul Catcher
Quartz Flask
League: Incursion
Source: Drops from unique{The Vaal Omnitect}
Upgrade: Upgrades to unique{Soul Ripper} via currency{Vial of the Ghost}
Requires Level 27
Cannot gain Mana during effect
Vaal Skills deal (60-100)% increased Damage during effect
Vaal Skills have 25% reduced Soul Cost during effect
Vaal Skills used during effect have (20-40)% reduced Soul Gain Prevention Duration
]],[[
Soul Ripper
Quartz Flask
League: Incursion
Source: Upgraded from unique{Soul Catcher} via currency{Vial of the Ghost}
Requires Level 27
100% increased Charges used
Vaal Skills deal (30-40)% more Damage during effect
Vaal Skills used during effect do not apply Soul Gain Prevention
Gains no Charges During effect of any Soul Ripper Flask
]],[[
Taste of Hate
Sapphire Flask
Variant: Pre 2.2.0
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 18
{variant:1}30% of Physical Damage taken as Cold Damage during Flask effect
{variant:2,3}20% of Physical Damage taken as Cold Damage during Flask effect
{variant:1,2}Gain (20-30)% of Physical Damage as Extra Cold Damage during effect
{variant:3}Gain (15-20)% of Physical Damage as Extra Cold Damage during effect
30% chance to Avoid being Chilled during Flask effect
30% chance to Avoid being Frozen during Flask effect
]],[[
The Overflowing Chalice
Sulphur Flask
Requires Level 35
Implicits: 1
Creates Consecrated Ground on Use
100% increased Charge Recovery
(10-20)% increased Duration
Gains no Charges during Effect of any Overflowing Chalice Flask
100% increased Charges gained by Other Flasks during Flask Effect
]],[[
The Sorrow of the Divine
Sulphur Flask
League: Legion
Source: Drops from normal{Templar} legion
Requires Level 35
Implicits: 1
Creates Consecrated Ground on Use
(25-50)% increased Duration
Zealot's Oath during Flask effect
Life Recovery from Flasks also applies to Energy Shield during Flask Effect
]],[[
Vessel of Vinktar
Topaz Flask
Source: Drops from unique{Avatar of Thunder} in unique{The Vinktar Square}
Variant: Pre 2.2.0 (Penetration)
Variant: Pre 2.2.0 (Spells)
Variant: Pre 2.2.0 (Attacks)
Variant: Pre 2.2.0 (Conversion)
Variant: Pre 3.0.0 (Penetration)
Variant: Pre 3.0.0 (Spells)
Variant: Pre 3.0.0 (Attacks)
Variant: {2_6}Pre 3.0.0 (Conversion)
Variant: Current (Penetration)
Variant: Current (Spells)
Variant: Current (Attacks)
Variant: Current (Conversion)
Requires Level 68
{variant:5,6,7,8,9,10,11,12}(80-100)% increased Charges used
{variant:1,2,3,4,5,6,7,8}Shocks nearby Enemies during Flask effect
{variant:9,10,11,12}Shocks nearby Enemies during Flask effect, causing 10% increased Damage taken
{variant:1,2,3,4,5,6,7,8}You are Shocked during Flask effect
{variant:9,10,11,12}You are Shocked during Flask effect, causing 50% increased Damage taken
{variant:1,2,3,4}30% of Lightning Damage Leeched as Life during Flask effect
{variant:5,6,7,8,9,10,11,12}20% of Lightning Damage Leeched as Life during Flask effect
{variant:1,2,3,4}30% of Lightning Damage Leeched as Mana during Flask effect
{variant:5,6,7,8}20% of Lightning Damage Leeched as Mana during Flask effect
{variant:1,2,3,4}Leech applies instantly during Flask effect
{variant:1,5,9}Damage Penetrates 10% Lightning Resistance during Flask effect
{variant:2,6,10}Adds (15-25) to (70-90) Lightning Damage to Spells during Flask effect
{variant:3,7,11}Adds (25-35) to (110-130) Lightning Damage to Attacks during Flask effect
{variant:4,8,12}20% of Physical Damage Converted to Lightning during Flask effect
]],[[
The Wise Oak
Bismuth Flask
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 8
Implicits: 0
During Flask Effect, 10% reduced Damage taken of each Element for which your Uncapped
Elemental Resistance is lowest
{variant:1}During Flask Effect, Damage Penetrates 20% Resistance of each Element for which your
Uncapped Elemental Resistance is highest
{variant:2}During Flask Effect, Damage Penetrates (10-15)% Resistance of each Element for which your
Uncapped Elemental Resistance is highest
]],[[
Witchfire Brew
Stibnite Flask
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 48
Implicits: 1
Creates a Smoke Cloud on Use
50% increased Charges used
{variant:1}(50-70)% increased Damage Over Time during Flask Effect
{variant:2}(25-40)% increased Damage Over Time during Flask Effect
Grants level 21 Despair Curse Aura during Flask Effect
]],
}
